
%% About This
% Noise contribution to TM displacement


%% Input & Output Port Setting
numi1=find(strcmp('azg',varinput));
numo1=find(strcmp('zF0',varoutput));
numo2=find(strcmp('zTM',varoutput));

%% Passive Model
[mag1,phs1]=mybodeacc(sysp(numo2,numi1),freq); % zg -> zTM

%% Feedback Model
[mag2,phs2]=mybodeacc(sysfb(4,1),freq); % zg -> zTM
[mag3,phs3]=mybode   (sysfb(4,4),freq); % LVDT noise -> zTM
[mag4,phs4]=mybode   (sysfb(4,5),freq); % GEO noise  -> zTM
[mag5,phs5]=mybode   (sysfb(4,6),freq); % ACT noise  -> zTM

%% High Pass Filter
wRLF = 2*pi*0.05; % 50 mHz
filter_LFreject = zpk([0;0],wRLF*[-1;-1],1);
[magHP,phHP]    = mybode(filter_LFreject,freq);

%% Import
kamioka =importdata('noisepsd\kamiokaNoisy.txt'   ); % Seismic Spectrum
GEO     =importdata('noisepsd\GeoNoiseDisp.txt'   ); % Geophone Noise
LVDT    =importdata('noisepsd\LVDTNoiseDisp.txt'  ); % LVDT Noise
ACTF0   =importdata('noisepsd\ACTNoiseF0Force.txt'); % Actuator Noise

%% Import
BRSE =importdata('noisepsd\varBRSEQN.dat'   ); % Seismic Spectrum
DRSE =importdata('noisepsd\varDRSEQN.dat'   ); % Geophone Noise

%% Noise Level
noise_seism = interp1(kamioka(:,1),kamioka(:,2),freq');  % [m/rtHz]
noise_seism = magHP.*noise_seism; % Reject low frequency (< 50mHz)
noise_GEO   = interp1(GEO(:,1),GEO(:,2),freq');          % [m/rtHz]
noise_LVDT  = interp1(LVDT(:,1),LVDT(:,2),freq');        % [m/rtHz]
noise_ACTF0 = interp1(ACTF0(:,1),ACTF0(:,2),freq');      % [N/rtHz]
rms_seism   = makerms(freq,noise_seism);  % RMS

%% Noise on TM

nTM_seismp  =mag1.*noise_seism;        % Passive Seismic
rmsTM_seismp=makerms(freq,nTM_seismp);
rmsTM_seismp_vel=makermsvel(freq,nTM_seismp);

nTM_seism   =mag2.*noise_seism;        % Active Seismic
rmsTM_seism =makerms(freq,nTM_seism);

nTM_geo     =mag4.*noise_GEO;          % GEO Noise
rmsTM_geo   =makerms(freq,nTM_geo);

nTM_LVDT    =mag3.*noise_LVDT;         % LVDT Noise
rmsTM_LVDT  =makerms(freq,nTM_LVDT);

nTM_ACTF0   =mag5.*noise_ACTF0;        % ACT Noise
rmsTM_ACTF0 =makerms(freq,nTM_ACTF0);

nTM_total = sqrt(nTM_seism.^2+nTM_geo.^2+nTM_LVDT.^2+nTM_ACTF0.^2);
rmsTM_total =makerms(freq,nTM_total);
rmsTM_total_vel=makermsvel(freq,nTM_total);

