
%% About This Script
% Suspension control simulator by T. Sekiguchi, since Oct. 2013
% The suspension models are imported from SUMCON in Mathematica.
% Type-A (for Test Masses) Full Model, only for Z and Pitch DoFs.

%% Start Calculation
clear all; %close all;
addpath('module');

%% Import Passive Suspension Model
TypeA_Z_140112; % Import ABCD Matrix
% Type-A SAS Model only for Z and Pitch DoFs
% IP tuned at 50 mHz, IM pitch mode tuned at 300 mHz

sysp=ss(ssA,ssB,ssC,ssD);
sysp.InputName=varinput;
sysp.OutputName=varoutput;

%% Set Constants
pp    = 2*pi;
g     = 9.81; % Gravity constant
alpha = 0;    % [rad/m] Translation-tilt coupling of IP 

%% Sensor Blending
blendLP  =  zpk([...
              szp(0.01265,0.6325) ... *
              szp(0.197,20) ... *
              szp(0.302,20) ... *
              ...szp(0.45,5)... *
              ],  ...
            [...          
              -pp*0.04... *
              szp(0.04,.5) ... * 
              szp(0.04,.5) ... *
              szp(0.197,2) ... * ... *
              -pp*0.4... *
         ], ...
         0.1108);
blendHP  = zpk([...  
              -pp*0 ... *            
              -pp*0 ... *            
              -pp*0 ... *
              szp(0.133,0.756) ...*
              ],  ...
            [...          
              -pp*0.04... *
              szp(0.04,.5) ... * 
              szp(0.04,.5) ... *
         ],...
         1);


%% Servo Filter
% IP Feedback Filter [N/m]
filterIPz = zpk([...  
            -pp*0.04 ...  
            -pp*0.04 ...
            ], ...
            [...
            -pp*0 ... 
            -pp*50 ... 
             szp(50,.5) ...
            ],...
            5e10);
gainIPz   =  -1;

%% Feedback Model
[a,b,c,d] = linmod('TypeA_IP_ctrl_140112');
sysfb     = ss(a,b,c,d);


%% Plot
fmin=-2.5;fmax=1.5;freq=logspace(fmin,fmax,1001);
% plot_GNDdispTF;        % TF from zg to zF0/zTM
% plot_GNDtiltTF;        % TF from pitchg to zF0/zTM
% plot_GNDdispTFpitch;   % TF from zg to pitchTM
% plot_BlendFiler;       % Blending filter
% plot_ServoFiler;       % Servo filter
plot_OpenLoopTF;       % Open loop transfer function

% plot_GNDdispTFCL;      % CLTF from zg to zF0/zTM

calc_NoiseTM;          % Noise contribution to zTM
% plot_NoiseModel;       % Sensor/act noise level
plot_NoiseTMbudget;    % Noise budget with active ctrl
% plot_NoiseTMcomp;      % Comparison: passive and active

%% Close Path Directory
% rmpath('module');
