
%% About This
% Plot transfer function from ground displacement to
% F0 and TM displacement in Passive Model

%% Input & Output Port Setting
numi1=find(strcmp('apitchg',varinput));
numo1=find(strcmp('zF0',varoutput));
numo2=find(strcmp('zTM',varoutput));

%% Calculation
[mag1,phs1]=mybodeacc(sysp(numo1,numi1),freq); % pitchgnd -> zF0
[mag2,phs2]=mybodeacc(sysp(numo2,numi1),freq); % pitchgnd -> zTM

%% Plot
magmin=-18;magmax=4;

figure(1012);

subplot(5,1,[1 2 3])
loglog(...
    freq,mag1,'r-',...
    freq,mag2,'b-',...
    'LineWidth',2)
legend(...
    'pitchGND -> zF0',...
    'pitchGND -> zTM',...
    'Location','SouthWest')
grid on
set(gca,'YTick',logspace(magmin,magmax,(magmax-magmin)/2+1))
ylim([10^(magmin) 10^(magmax)])
xlim([10^(fmin)   10^(fmax)  ])
title('Transfer function from Gnd tilt to F0/TM displacement',...
      'FontSize',16,'FontWeight','bold')
ylabel('Magnitude [m/rad]','FontSize',14,'FontWeight','bold')
set(gca,'FontSize',14)

subplot(5,1,[4 5])
semilogx(...
    freq,phs1,'r-',...
    freq,phs2,'b-',...
    'LineWidth',2)
grid on
ylim([-180 180])
xlim([10^(fmin) 10^(fmax)])
ylabel('Phase [deg]','FontSize',14,'FontWeight','bold')
xlabel('Frequency [Hz]','FontSize',14,'FontWeight','bold')
set(gca,'FontSize',14)
set(gca,'YTick',-180:90:180)
